path_from: Get file path starting at a certain path component

View source: R/bucket.R

path_fromR Documentation

Get file path starting at a certain path component

Description

Get file path starting at a certain path component

Usage

path_from(path, from)

Value

a single file path of class fs_path/character

Examples

path_from(path = "Rtmpxsqth0/apples/mcintosh/orange.csv", from = "apples")

sixtyfour documentation built on Aug. 28, 2026, 9:06 a.m.